@@ -1,4 +1,5 @@
-package Test::YA::CLI::Example::Something;
+package
+    Test::YA::CLI::Example::Something;
 use Moo;
 use namespace::autoclean;
 
